@@ -1,3 +1,5 @@
+use std::num::{ParseFloatError, ParseIntError};
+
 use super::*;
 
 macro_rules! error_wrap {
@@ -29,3 +31,15 @@ impl From<()> for TailwindError {
         Self::unreachable()
     }
 }
+
+impl From<ParseIntError> for TailwindError {
+    fn from(e: ParseIntError) -> Self {
+        Self::syntax_error(e.to_string())
+    }
+}
+
+impl From<ParseFloatError> for TailwindError {
+    fn from(e: ParseFloatError) -> Self {
+        Self::syntax_error(e.to_string())
+    }
+}
